<template>
  <div>
    <el-dialog
      :title="title"
      :visible.sync="show"
      width="65%"
      :destroy-on-close="true"
      :close-on-click-modal="false"
      :modal="false"
      :before-close="close">
      <el-tree
        ref="tree"
        :data="deptTree"
        show-checkbox
        node-key="id"
        :check-strictly="true"
        :default-expanded-keys="['dept:100']"
        @check-change="handleCheckChange"
        >
      </el-tree>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submit">确 定</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import {flowableDeptTreeSelect} from "@/api/system/user";

export default {
  name: "MyDept",
  props: {
    show: {
      required: true,
      type: Boolean
    },
    title: {
      type: String,
      required: false,
      default: '候选部门'
    },
    checkeds: {
      required: true
    }
  },
  watch: {
    checkeds: {
      handler(newV) {
        if (newV && newV.length > 0) {
          this.checkList = newV
          this.$nextTick(() => {
            if (this.$refs.tree) {
              this.$refs.tree.setCheckedKeys(newV.map(item => item.id));
            }
          });
        } else {
          this.checkList = []
        }
      },
      deep: true
    },
  },
  data() {
    return {
      deptTree: [],
      checkList: [],
    }
  },
  created() {
    flowableDeptTreeSelect().then(res => {
      this.deptTree = res.data
    })
  },
  methods: {
    setCheckList(newV) {
      if (newV && newV.length > 0) {
        this.checkList = newV
        this.$nextTick(() => {
          if (this.$refs.tree) {
            this.$refs.tree.setCheckedKeys(newV.map(item => item.id));
          }
        });
      } else {
        this.checkList = []
      }
    },
    handleCheckChange(data, checked, indeterminate) {
      if (checked) {
        if (this.checkList.every(item => item.id !== data.id)) {
          this.checkList.push(data)
        }
      } else {
        this.checkList = this.checkList.filter(item => item !== data)
      }
      console.log(data, checked, indeterminate);
    },
    close() {
      this.$emit("close")
    },
    submit() {
      this.$emit("submit", this.checkList)
    }
  }
}
</script>

<style scoped>

</style>
